@@ -62,7 +62,7 @@ let discover_existing_apps config =
   !already_installed
 
 let by_name_ignore_case (n1, p1, u1) (n2, p2, u2) =
-  let r = String.compare (String.lowercase n1) (String.lowercase n2) in
+  let r = String.compare (String.lowercase_ascii n1) (String.lowercase_ascii n2) in
   if r <> 0 then r
   else compare (p1, u1) (p2, u2)
 
@@ -100,7 +100,7 @@ let show_help config sel =
   U.xdg_open_dir ~exec:false system path
 
 let get_selections tools ~(gui:Ui.ui_handler) uri =
-  let reqs = Requirements.default_requirements uri in
+  let reqs = Requirements.run uri in
   match Driver.quick_solve tools reqs with
   | Some sels -> Lwt.return (`Success sels)
   | None ->
@@ -244,7 +244,7 @@ let create config ~gui ~tools ~add_app =
 
   edit_item#connect#activate ==> (fun () ->
     let uri = !menu_iface |? lazy (raise_safe "BUG: no selected item!") in
-    let reqs = Requirements.default_requirements uri in
+    let reqs = Requirements.run uri in
     Gtk_utils.async ~parent:dialog (fun () ->
       gui#run_solver tools `Download_only reqs ~refresh:false >|= ignore
     )
