@@ -332,7 +332,7 @@ let make_feeds_tab tools ~trust_db ~recalculate ~watcher window iface =
       if iter#has_tag link_style then (
         let start = iter#backward_to_tag_toggle (Some link_style) in
         let stop = iter#forward_to_tag_toggle (Some link_style) in
-        let target = start#get_text ~stop |> trim in
+        let target = start#get_text ~stop |> String.trim in
         open_in_browser config.system target;
         true
       ) else false
@@ -387,8 +387,8 @@ let build_stability_menu set_stability =
 
   GMenu.separator_item ~packing:menu#add () |> ignore_widget;
 
-  [Preferred; Packaged; Stable; Testing; Developer; Buggy; Insecure] |> List.iter (fun stability ->
-    let label = Impl.format_stability stability |> String.capitalize in
+  Stability.[Preferred; Packaged; Stable; Testing; Developer; Buggy; Insecure] |> List.iter (fun stability ->
+    let label = Stability.to_string stability |> String.capitalize_ascii in
     let item = GMenu.menu_item ~packing:menu#add ~label () in
     item#connect#activate ==> (fun () -> set_stability (Some stability))
   );
@@ -453,13 +453,13 @@ let make_versions_tab config reqs ~recalculate ~watcher window role =
 
   let iface_config = FC.load_iface_config config iface in
 
-  Preferences_box.combo
+  Gtk_utils.combo
     ~table ~top:0 ~label:"Preferred stability: "
-    ~choices:[None; Some Stable; Some Testing; Some Developer]
+    ~choices:Stability.[None; Some Stable; Some Testing; Some Developer]
     ~value:iface_config.FC.stability_policy
     ~to_string:(function
       | None -> "Use default setting"
-      | Some level -> Impl.format_stability level |> String.capitalize
+      | Some level -> Stability.to_string level |> String.capitalize_ascii
     )
     ~callback:set_stability_policy
     ~tooltip:"Implementations at this stability level or higher will be used in preference to others. \
@@ -574,7 +574,7 @@ let make_versions_tab config reqs ~recalculate ~watcher window role =
         let overrides = get_overrides from_feed in
         let stability_value =
           match StringMap.find impl_id overrides.F.user_stability with
-          | Some user_stability -> Impl.format_stability user_stability |> String.uppercase
+          | Some user_stability -> Stability.to_string user_stability |> String.uppercase_ascii
           | None -> Q.AttrMap.get_no_ns FeedAttr.stability impl.Impl.props.Impl.attrs |> default "testing" in
 
         let arch_value =
