@@ -1,4 +1,4 @@
-(* Copyright (C) 2013, Thomas Leonard
+(* Copyright (C) 2017, Thomas Leonard
  * See the README file for details, or visit http://0install.net.
  *)
 
@@ -21,6 +21,10 @@ type details = {
   dir : string;
 }
 
+let ci_build =
+  try Sys.getenv "CI" = "true"
+  with Not_found -> false
+
 let get_info package =
   (* Windows can't handle newlines or tabs in the format string, so use ASCII unit separator. *)
   let c_out, c_in, c_err = Unix.open_process_full ("ocamlfind query -format %v\x1f%d " ^ package) (Unix.environment ()) in
@@ -71,12 +75,6 @@ let windres =
         "x86_64-w64-mingw32-windres.exe"
 
 let () =
-  let v = Sys.ocaml_version in
-  let first_dot = String.index v '.' in
-  let second_dot = String.index_from v (first_dot + 1) '.' in
-  let major_version = int_of_string (String.sub v 0 first_dot) in
-  let minor_version = int_of_string (String.sub v (first_dot + 1) (second_dot - first_dot - 1)) in
-
   let native_targets = ref ["static_0install.native"] in
 
   if Sys.os_type = "Win32" then native_targets := "runenv.native" :: !native_targets;
@@ -116,7 +114,9 @@ let () =
   (* When building byte-code, we need -custom to include the C code *)
   flag ["link"; "ocaml"; "byte"] (A"-custom");
 
-  dispatch (function
+  dispatch @@ fun hook ->
+  Ocamlbuild_cppo.dispatcher hook;
+  match hook with
   | Before_options ->
       Options.make_links := false;
       Options.use_ocamlfind := true;
@@ -146,45 +146,41 @@ let () =
     pdep ["link"] "linkdep_win" (fun param -> if on_windows then [param] else []);
     pdep ["link"] "link" (fun param -> [param]);
 
-    let have_ocurl_lwt =
-      match get_info "curl" with
-      | Some {version; dir = _} -> parse_version version >= [0; 7; 1]
-      | None -> failwith "Missing curl!" in
+    begin match get_info "curl" with
+    | None -> failwith "Missing ocurl!"
+    | Some {version; dir = _} ->
+      if parse_version version < [0; 7; 1] then
+        failwith "ocurl is too old - need 0.7.1 or later"
+    end;
 
     let have_sha = get_info "sha" <> None in
 
-    if have_ocurl_lwt then
-      flag ["link"] (S [A"-package"; A"curl.lwt"]);
-
-    if not have_ocurl_lwt || not have_sha then (
+    if not have_sha then (
       flag ["compile"] (S [A"-package"; A"ssl"]);
       flag ["link"] (S [A"-package"; A"ssl"]);
     );
 
     begin match gtk_dir with
-    | Some gtk_dir ->
-        let lwt_dir =
-          match get_info "lwt.glib" with
-          | Some {version=_; dir} -> dir
-          | None -> failwith "lablgtk2 is present, but missing lwt.glib dependency!" in
-        (* ("-thread" is needed on Ubuntu 13.04 for some reason, even though it's in the _tags too) *)
-        flag ["library"; "native"; "link_gtk"] (S [A"-thread"; A (gtk_dir / "lablgtk.cmxa"); A (lwt_dir / "lwt-glib.cmxa")]);
-        flag ["library"; "byte"; "link_gtk"] (S [A"-thread"; A (gtk_dir / "lablgtk.cma"); A (lwt_dir / "lwt-glib.cma")]);
-    | None -> () end;
-
-    (* We use mypp rather than camlp4of because if you pass -pp and -ppopt to ocamlfind
-       then it just ignores the ppopt. So, we need to write the -pp option ourselves. *)
-
-    let defines_portable = ref [] in
-    if (major_version < 4 || (major_version == 4 && minor_version < 1)) then add "-DOCAML_LT_4_01" defines_portable;
-    if (major_version < 4 || (major_version == 4 && minor_version < 2)) then add "-DOCAML_LT_4_02" defines_portable;
-    if use_dbus then add "-DHAVE_DBUS" defines_portable;
-    if gtk_dir <> None then add "-DHAVE_GTK" defines_portable;
-    if have_ocurl_lwt then add "-DHAVE_OCURL_LWT" defines_portable;
+      | None -> ()
+      | Some gtk_dir ->
+        match get_info "lwt.glib" with
+          | Some {version; dir = lwt_dir} -> (* Lwt 3 < 3 *)
+            print_endline "Linking with old lwt.glib structure";
+            flag ["library"; "shared"; "native"; "link_gtk"] (S [A"-thread"; A (gtk_dir / "lablgtk.cmxa"); A (lwt_dir / "lwt-glib.cmxa")]);
+            flag ["library"; "byte"; "link_gtk"] (S [A"-thread"; A (gtk_dir / "lablgtk.cma"); A (lwt_dir / "lwt-glib.cma")]);
+          | None ->   (* Lwt >= 3 *)
+            let lwt_dir =
+              match get_info "lwt_glib" with
+              | Some {version=_; dir} -> dir
+              | None -> failwith "lablgtk2 is present, but missing lwt_glib dependency!" in
+            (* ("-thread" is needed on Ubuntu 13.04 for some reason, even though it's in the _tags too) *)
+            flag ["library"; "shared"; "native"; "link_gtk"] (S [A"-thread"; A (gtk_dir / "lablgtk.cmxa"); A (lwt_dir / "lwt_glib.cmxa")]);
+            flag ["library"; "byte"; "link_gtk"] (S [A"-thread"; A (gtk_dir / "lablgtk.cma"); A (lwt_dir / "lwt_glib.cma")]);
+    end;
 
     if have_sha then (
       (* Use "sha" package instead of libcrypto *)
-      add "-DHAVE_SHA" defines_portable;
+      flag ["cppo"] (S [A "-D"; A "HAVE_SHA"]);
       flag ["compile"; "link_crypto"] (S [A"-ccopt"; A"-DHAVE_SHA"]);
       flag ["compile"; "ocaml"] (S [A"-package"; A"sha"]);
       flag ["link"] (S [A"-package"; A"sha"]);
@@ -192,8 +188,8 @@ let () =
       print_endline "sha (ocaml-sha) not found; using OpenSSL instead"
     );
 
-    let defines_native = ref !defines_portable in
-    if on_windows then add "-DWINDOWS" defines_native;
+    if on_windows then
+      flag ["cppo"] (S [A "-D"; A "WINDOWS"]);
 
     if gtk_dir <> None then (
       let add_glib tag =
@@ -201,13 +197,11 @@ let () =
       List.iter add_glib ["compile"; "ocamldep"; "doc"; "link"; "infer_interface"]
     );
 
-    flag ["native";"ocaml";"pp";"mypp"] (S (A "camlp4of" :: !defines_native));
-    flag ["byte";"ocaml";"pp";"mypp"] (S (A "camlp4of" :: !defines_portable));
+    if use_dbus then
+      flag ["cppo"] (S [A "-D"; A "HAVE_DBUS"]);
 
-    flag ["ocaml";"ocamldep";"mypp"] (S [A"-pp"; A "camlp4of"]);
-
-    (* Enable most warnings *)
-    flag ["compile"; "ocaml"] (S [A"-w"; A"A-4-48"; A"-warn-error"; A"+5+6+10+26"]);
+    (* Make all enabled warnings fatal for CI builds. *)
+    if ci_build then flag ["compile"; "ocaml"] (S [A"-warn-error"; A"A-4-48-58"]);
 
     pflag [] "dllib" (fun x -> (S [A"-dllib"; A x]));
 
@@ -223,5 +217,3 @@ let () =
       flag ["link"] (S [A"-package"; A"bisect"]);
     );
   | _ -> ()
-  )
-
