@@ -4,10 +4,25 @@
 
 open Common
 
+type t = system
+
 module U = Utils
 
 let spf = Printf.sprintf
 
+let gpg_lock = Lwt_mutex.create ()
+(* gnupg does not work reliably when multiple processes are using the keyring at once (at least on OS X).
+   Example error without the lock:
+
+   warning: Feed http://0install.net/2006/interfaces/0publish: Failed to check feed signature:
+   Error checking signature for 'http://0install.net/2006/interfaces/0publish': GPG failed:
+   gpg: starting migration from earlier GnuPG versions
+   gpg: porting secret keys from '/Users/travis/.gnupg/secring.gpg' to gpg-agent
+   gpg: migration succeeded
+   gpg: can't open '/Users/travis/.gnupg/pubring.gpg'
+   gpg: keydb_get_keyblock failed: Value not found
+ *)
+
 type fingerprint = string
 type timestamp = float
 
@@ -39,6 +54,8 @@ let re_newline = Str.regexp "[\n\r]+"
 
 let gnupg_options = ref None
 
+let make system = system
+
 let get_gnupg_options system =
   let gpg_path =
     match system#getenv "ZEROINSTALL_GPG" with
@@ -105,9 +122,10 @@ let run_gpg_full system ?stdin args =
  * If the command returns an error, report stderr as the error (on success, stderr is discarded).
  *)
 let run_gpg system ?stdin args =
+  Lwt_mutex.with_lock gpg_lock @@ fun () ->
   run_gpg_full system ?stdin args >>= fun (stdout, stderr, status) ->
-  if stdout <> "" then log_info "GPG: output:\n%s" (trim stdout);
-  if stderr <> "" then log_info "GPG: warnings:\n%s" (trim stderr);
+  if stdout <> "" then log_info "GPG: output:\n%s" (String.trim stdout);
+  if stderr <> "" then log_info "GPG: warnings:\n%s" (String.trim stderr);
   match status with
   | Unix.WEXITED 0 -> Lwt.return stdout
   | status ->
@@ -171,7 +189,9 @@ let make_valid args = ValidSig {
 let make_bad args = BadSig args.(0)
 
 let make_err args = ErrSig (
-  match U.safe_int_of_string args.(5) with
+  (* GnuPG 2.1.16 sets the higher bits (possibly by mistake).
+     See: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=846834 *)
+  match U.safe_int_of_string args.(5) land 0xffff with
   | 4 -> UnsupportedAlgorithm args.(1)
   | 9 -> UnknownKey args.(0)
   | x -> UnknownSigError x
@@ -226,7 +246,7 @@ let verify (system:system) xml =
           (open_out_bin tmp)
           (fun ch -> output_string ch sig_data);
 
-        let write_stdin stdin = Lwt_io.write_from_exactly stdin xml 0 index in
+        let write_stdin stdin = Lwt_io.write_from_string_exactly stdin xml 0 index in
         run_gpg_full system ~stdin:write_stdin [
             (* Not all versions support this: *)
             (* '--max-output', str(1024 * 1024), *)
@@ -245,7 +265,7 @@ let verify (system:system) xml =
       )
     >>= fun (stdout, stderr, exit_status) ->
     ignore exit_status;
-    Lwt.return (sigs_from_gpg_status_output stdout, trim stderr)
+    Lwt.return (sigs_from_gpg_status_output stdout, String.trim stderr)
   )
 
 type key_info = {
