@@ -62,24 +62,26 @@ let console_handler ?ex level msg =
 
 let handler = ref console_handler
 
-(* [fmt] has type ('a, unit, string, unit) format4, which means:
-   - we accept any a format with variables type (e.g. "got:%s" has type string -> unit)
-   - any custom print function passed by the caller has type unit -> string
-   - the final result of the whole thing is unit
- *)
+let kasprintf k fmt =
+  let b = Buffer.create 512 in
+  let ppf = Format.formatter_of_buffer b in
+  let cb f =
+    Format.pp_print_flush f ();
+    k (Buffer.contents b) in
+  Format.kfprintf cb ppf fmt
 
-let log level ?ex =
-  let do_log msg =
+let asprintf fmt = kasprintf (fun s -> s) fmt
+
+let log level ?ex fmt =
+  kasprintf (fun msg ->
     if level >= !threshold then
       !handler ?ex level msg;
-
     match !crash_log with
     | None -> ()
     | Some crash_log ->
         crash_log.entries <- (Unix.gettimeofday (), ex, level, msg) :: crash_log.entries;
         if level >= Warning then dump_crash_log ()
-  in
-  Printf.ksprintf do_log
+  ) fmt
 
 let log_debug ?ex fmt = log Debug ?ex fmt
 
