@@ -6,7 +6,7 @@ open Support.Common
 module U = Support.Utils
 
 let write fd msg =
-  Lwt_unix.write fd msg 0 (String.length msg) >>= fun wrote ->
+  Lwt_unix.write_string fd msg 0 (String.length msg) >>= fun wrote ->
   assert (wrote = String.length msg);
   Lwt.return ()
 
@@ -33,7 +33,7 @@ let handle_connection client =
 
 let run gpg_dir =
   let socket = Lwt_unix.(socket PF_UNIX SOCK_STREAM 0) in
-  Lwt_unix.bind socket (Lwt_unix.ADDR_UNIX (gpg_dir +/ "S.gpg-agent"));
+  Unix.bind (Lwt_unix.unix_file_descr socket) (Lwt_unix.ADDR_UNIX (gpg_dir +/ "S.gpg-agent"));
   Lwt_unix.set_close_on_exec socket;
   Lwt_unix.listen socket 5;
   let rec aux () =
@@ -51,6 +51,7 @@ let run gpg_dir =
 
 let with_gpg test =
   Fake_system.with_tmpdir (fun tmpdir ->
+    OUnit.skip_if on_windows "No PF_UNIX on Windows";
     let agent = run tmpdir in
     Lwt_main.run (
       Lwt.finalize
