@@ -44,6 +44,7 @@ let test_basedir () =
   equal_str_lists ~msg:"XDG3" ["/home/bob/.local/share"; "/data1"; "/data2"] bd.data
 
 let test_portable_base () =
+  skip_if (Sys.os_type = "Win32") "Tests Unix paths";
   let system = new fake_system None in
   system#putenv "HOME" "/home/bob";
   let paths = Paths.get_default (system :> system) in
@@ -103,8 +104,8 @@ let test_option_parsing () =
 
   let p args = let (options, _flags, _args) = p_full args in options in
 
-  assert_equal Maybe (p ["select"]).tools#use_gui;
-  assert_equal No (p ["--console"; "select"]).tools#use_gui;
+  assert_equal `Auto (p ["select"]).tools#use_gui;
+  assert_equal `No (p ["--console"; "select"]).tools#use_gui;
 
   let _, _, args = p_full ["--with-store"; "/data/store"; "run"; "foo"] in
   assert_equal "/data/store" (List.nth config.stores @@ List.length config.stores - 1);
@@ -119,7 +120,7 @@ let test_option_parsing () =
 
   assert (List.length (fake_log#get) = 0);
   let s = p ["-cvv"; "run"] in
-  assert_equal No s.tools#use_gui;
+  assert_equal `No s.tools#use_gui;
   assert_equal 2 s.verbosity;
   assert (List.length (fake_log#get) > 0);
 
@@ -315,15 +316,12 @@ let show_log_on_failure fn () =
     );
     raise ex
 
-(* Actually, we just want a recent Lwt, but this will do. *)
-IFNDEF OCAML_LT_4_01 THEN
 let () =
   Lwt.async_exception_hook := (fun ex ->
     async_exception := Some ex;
     Printf.fprintf orig_stderr "Async exception: %s" (Printexc.to_string ex);
     flush orig_stderr
   )
-ENDIF
 
 let is_error = function
   | RFailure _ | RError _ -> true
