@@ -15,6 +15,13 @@ module Q = Support.Qdom
 
 let cache_path_for config url = Feed_cache.get_save_cache_path config url
 
+let re_backslash = Str.regexp_string "\\"
+let re_win_root = Str.regexp_string "c:\\root\\"
+
+let fixup_windows_paths str =
+  Str.global_replace re_win_root "/root/" str
+  |> Str.global_replace re_backslash "/"
+
 let make_packagekit get_distro_candidates =
   object (_ : Zeroinstall.Packagekit.packagekit)
     val candidates = Hashtbl.create 10
@@ -37,7 +44,7 @@ let make_packagekit get_distro_candidates =
     method install_packages _ui _names = failwith "install_packages"
   end
 
-let fake_fetcher config handler (distro:Zeroinstall.Distro.distribution) =
+let fake_fetcher config handler (distro:Zeroinstall.Distro.t) =
   let fetcher =
     object
       method download_and_import_feed (`Remote_feed url) =
@@ -70,11 +77,14 @@ let make_driver_test test_elem =
   ZI.check_tag "test" test_elem;
   let name = ZI.get_attribute "name" test_elem in
   name >:: Fake_system.with_tmpdir (fun tmpdir ->
+    match ZI.get_attribute_opt "skip-windows" test_elem with
+    | Some reason when on_windows -> skip_if true reason
+    | _ ->
     let (config, fake_system) = Fake_system.get_fake_config (Some tmpdir) in
     let home = U.getenv_ex config.system "HOME" in
     let expand_tmp s =
       Str.global_replace (Str.regexp_string "@TMP@") tmpdir s in
-    let reqs = ref (Zeroinstall.Requirements.default_requirements "") in
+    let reqs = ref (Zeroinstall.Requirements.run "") in
     let fails = ref false in
     let expected_problem = ref "missing-problem" in
     let expected_output = ref "missing-output" in
@@ -110,7 +120,7 @@ let make_driver_test test_elem =
         child |> ZI.iter ~name:"arg" (fun arg ->
           args := arg.Support.Qdom.last_text_inside :: !args
         )
-    | Some "problem" -> expected_problem := trim child.Support.Qdom.last_text_inside
+    | Some "problem" -> expected_problem := String.trim child.Support.Qdom.last_text_inside
     | Some "download" -> expected_digests := StringSet.add (ZI.get_attribute "digest" child) !expected_digests
     | Some "set-env" ->
         let name = ZI.get_attribute "name" child in
@@ -151,7 +161,7 @@ let make_driver_test test_elem =
             | `Aborted_by_user -> assert false in
           if !fails then assert_failure "Expected run_solver to fail, but it didn't!";
           let actual_env = ref StringMap.empty in
-          let output = trim @@ Fake_system.capture_stdout (fun () ->
+          let output = String.trim @@ Fake_system.capture_stdout (fun () ->
             let exec cmd ~env =
               ArrayLabels.iter env ~f:(fun binding ->
                 let (name, value) = Support.Utils.split_pair Support.Utils.re_equals binding in
@@ -162,6 +172,7 @@ let make_driver_test test_elem =
             | `Dry_run msg -> Zeroinstall.Dry_run.log "%s" msg
             | `Ok () -> ()
           ) in
+          let output = if on_windows then fixup_windows_paths output else output in
           let re = Str.regexp !expected_output in
           if not (Str.string_match re output 0) then
             assert_failure (Printf.sprintf "Expected output '%s' but got '%s'" !expected_output output);
@@ -184,7 +195,7 @@ let make_driver_test test_elem =
 let suite = "driver">::: [
   "simple">:: Fake_system.with_tmpdir (fun tmpdir ->
     let (config, _fake_system) = Fake_system.get_fake_config (Some tmpdir) in
-    let reqs = Requirements.({(default_requirements "http://example.com/prog.xml") with command = None}) in
+    let reqs = Requirements.({(run "http://example.com/prog.xml") with command = None}) in
     let handler =
       object
         method download_impls = failwith "download_impls"
@@ -207,7 +218,7 @@ let suite = "driver">::: [
       | name -> failwith name in
 
     let packagekit = lazy (make_packagekit get_distro_candidates) in
-    let distro = Distro_impls.generic_distribution ~packagekit config in
+    let distro = Distro_impls.generic_distribution ~packagekit config |> Distro.of_provider in
     let tools = fake_fetcher config handler distro in
     let (ready, result, _fp) = Driver.solve_with_downloads config tools#distro tools#fetcher ~watcher:tools#ui#watcher reqs ~force:true ~update_local:true |> Lwt_main.run in
     if not ready then
@@ -222,7 +233,7 @@ let suite = "driver">::: [
   "noNeedDl">:: Fake_system.with_tmpdir (fun tmpdir ->
     let (config, _fake_system) = Fake_system.get_fake_config (Some tmpdir) in
     let foo_path = Test_0install.feed_dir +/ "Foo.xml" in
-    let reqs = Requirements.({(default_requirements foo_path) with command = None}) in
+    let reqs = Requirements.({(run foo_path) with command = None}) in
     let tools = Fake_system.make_tools config in
     match Fake_system.null_ui#run_solver tools `Select_for_run reqs ~refresh:false |> Lwt_main.run with
     | `Success _ -> ()
@@ -236,15 +247,15 @@ let suite = "driver">::: [
       U.copy_file config.system (Test_0install.feed_dir +/ name) (cache_path_for config @@ `Remote_feed ("http://foo/" ^ name)) 0o644 in
     import "Binary.xml";
     let distro =
-      object (_ : Distro.distribution)
+      Distro.of_provider @@ object (_ : Distro.provider)
         method is_valid_package_name _ = true
-        method is_installed_quick = failwith "is_installed"
-        method get_impls_for_feed ?init:_ ~problem:_ _feed = StringMap.empty
+        method is_installed = failwith "is_installed"
+        method get_impls_for_feed ~problem:_ _feed = StringMap.empty
         method check_for_candidates = raise_safe "Unexpected check_for_candidates"
         method install_distro_packages = raise_safe "install_distro_packages"
         method match_name = (=) "dummy"
       end in
-    let reqs = Requirements.default_requirements "http://foo/Binary.xml" in
+    let reqs = Requirements.run "http://foo/Binary.xml" in
     let fetcher =
       object
         method download_and_import_feed (`Remote_feed url) = raise_safe "download_and_import_feed: %s" url
