@@ -27,7 +27,7 @@ let impl_template = Impl.({
     bindings = [];
     commands = StringMap.empty;
   };
-  stability = Testing;
+  stability = Stability.Testing;
   os = None;
   machine = None;
   parsed_version = Zeroinstall.Version.parse "1.0";
@@ -37,10 +37,16 @@ let impl_template = Impl.({
   };
 })
 
-let parse_xml s =
-  let s = "<root xmlns='http://zero-install.sourceforge.net/2004/injector/interface'>" ^ s ^ "</root>" in
-  let root = `String (0, s) |> Xmlm.make_input |> Q.parse_input None in
-  List.hd root.Q.child_nodes
+let parse_recipe s =
+  let s = Printf.sprintf
+      "<interface xmlns='http://zero-install.sourceforge.net/2004/injector/interface'> \n\
+        <name>Test</name> \n\
+        <implementation id='sha1=123'>%s</implementation> \n\
+       </interface>" s in
+  let feed = `String (0, s) |> Xmlm.make_input |> Q.parse_input None |> Element.parse_feed in
+  match Element.group_children feed with
+  | [`Implementation impl] -> Element.retrieval_methods impl
+  | _ -> assert false
 
 let make_dl_tester () =
   let log = ref [] in
@@ -79,6 +85,7 @@ let make_dl_tester () =
 
 let suite = "fetch">::: [
   "download-local">:: Fake_system.with_fake_config (fun (config, _fake_system) ->
+    skip_if on_windows "mtime returns -1";
     let tools = Fake_system.make_tools config in
     let fetcher = tools#make_fetcher tools#ui#watcher in
     download_impls fetcher [];
@@ -87,10 +94,10 @@ let suite = "fetch">::: [
       (fun () -> download_impls fetcher [impl_template]);
 
     let try_with ?(template = impl_template) ?(digest=("sha1new", "123")) xml =
-      let recipe = parse_xml xml in
+      let recipe = parse_recipe xml in
       let impl_type = Impl.(`Cache_impl {
         digests = [digest];
-        retrieval_methods = [recipe];
+        retrieval_methods = recipe;
       }) in
       let impl = Impl.({template with impl_type}) in
       download_impls fetcher [impl] in
@@ -160,6 +167,7 @@ let suite = "fetch">::: [
   );
 
   "local-archive">:: Fake_system.with_fake_config (fun (config, fake_system) ->
+    skip_if on_windows "Pathnames cause trouble for tar on Windows";
     let tools = Fake_system.make_tools config in
     let fetcher = tools#make_fetcher tools#ui#watcher in
 
@@ -204,8 +212,8 @@ let suite = "fetch">::: [
     let sels = `String (0, xml) |> Xmlm.make_input |> Q.parse_input None |> Zeroinstall.Selections.create in
     assert (Zeroinstall.Driver.get_unavailable_selections config ~distro:tools#distro sels <> []);
 
-    check ~error:"Local file '.*tests/IDONTEXIST.tgz' does not exist" "impl2";
-    check ~error:"Wrong size for .*/tests/HelloWorld.tgz: feed says 177, but actually 176 bytes" "impl3";
+    check ~error:"Local file '.*tests.IDONTEXIST.tgz' does not exist" "impl2";
+    check ~error:"Wrong size for .*.tests.HelloWorld.tgz: feed says 177, but actually 176 bytes" "impl3";
     check ~testfile:"HelloWorld" "impl1";
     check ~testfile:"archive.tgz" "impl4";
   );
