@@ -63,8 +63,8 @@ let xml_diff exp actual =
     ) else if a.tag <> b.tag then (
       p "Namespace '%s' vs '%s'\n" (fst a.tag) (fst a.tag); true
     ) else (
-      assert_equal ~printer:(fun s -> s) (trim a.text_before) (trim b.text_before);
-      assert_equal ~printer:(fun s -> s) (trim a.last_text_inside) (trim b.last_text_inside);
+      assert_equal ~printer:(fun s -> s) (String.trim a.text_before) (String.trim b.text_before);
+      assert_equal ~printer:(fun s -> s) (String.trim a.last_text_inside) (String.trim b.last_text_inside);
       ListString.assert_equal (set_of_attrs a) (set_of_attrs b);
       if List.length a.child_nodes <> List.length b.child_nodes then (
         p "Number of child nodes differs\n"; true
@@ -107,7 +107,7 @@ let linux_multi_scope_filter = { Scope_filter.
   may_compile = false;
 }
 
-class fake_feed_provider system (distro:Distro.distribution option) =
+class fake_feed_provider system (distro:Distro.provider option) =
   let ifaces = Hashtbl.create 10 in
 
   object (_ : #Feed_provider.feed_provider)
@@ -174,7 +174,7 @@ let make_solver_test test_elem =
     );
     fake_system#add_dir fake_system#getcwd [];
     let system = (fake_system :> system) in
-    let reqs = ref (Zeroinstall.Requirements.default_requirements "") in
+    let reqs = ref (Zeroinstall.Requirements.run "") in
     let fails = ref false in
     let expected_selections = ref (ZI.make "missing") in
     let expected_problem = ref "missing" in
@@ -215,7 +215,7 @@ let make_solver_test test_elem =
         );
         fails := ZI.get_attribute_opt "fails" child = Some "true"
     | Some "selections" -> expected_selections := child
-    | Some "problem" -> expected_problem := trim child.Support.Qdom.last_text_inside
+    | Some "problem" -> expected_problem := String.trim child.Support.Qdom.last_text_inside
     | Some "justification" -> justifications := child :: !justifications
     | _ -> Support.Qdom.raise_elem "Unexpected element" child in
     ZI.iter process test_elem;
@@ -233,7 +233,7 @@ let make_solver_test test_elem =
 
     if (!fails) then
       let reason = Zeroinstall.Solver.get_failure_reason config result in
-      Fake_system.assert_str_equal !expected_problem reason
+      Fake_system.assert_str_equal !expected_problem (Test_driver.fixup_windows_paths reason)
     else (
       let actual_sels = Solver.selections result in
       (* Selections.as_xml actual_sels |> Q.reindent |> Q.to_utf8 |> print_endline; *)
@@ -254,7 +254,7 @@ let make_solver_test test_elem =
         id = ZI.get_attribute "id" elem;
       }) in
       let reason = Zeroinstall.Justify.justify_decision config (feed_provider :> Feed_provider.feed_provider) !reqs iface ~source:false g_id in
-      Fake_system.assert_str_equal (trim elem.Support.Qdom.last_text_inside) reason
+      Fake_system.assert_str_equal (String.trim elem.Support.Qdom.last_text_inside) reason
     );
   )
 
@@ -429,12 +429,12 @@ let suite = "solver">::: [
           match super#get_feed url with
           | None -> None
           | Some (feed, overrides) ->
-              let overrides = {overrides with Feed.user_stability = StringMap.singleton "preferred_by_user" Preferred} in
+              let overrides = {overrides with Feed.user_stability = StringMap.singleton "preferred_by_user" Stability.Preferred} in
               Some (feed, overrides)
 
         method! get_distro_impls feed =
           let result = super#get_distro_impls feed in
-          let overrides = {result.Feed_provider.overrides with Feed.user_stability = StringMap.singleton "package:buggy" Buggy} in
+          let overrides = {result.Feed_provider.overrides with Feed.user_stability = StringMap.singleton "package:buggy" Stability.Buggy} in
           {result with Feed_provider.overrides}
       end in
     feed_provider#add_iface (Support.Qdom.parse_file Fake_system.real_system (Fake_system.tests_dir +/ "ranking.xml"));
@@ -541,7 +541,7 @@ let suite = "solver">::: [
     assert_equal 3 (List.length comp_impls.Impl_provider.impls);
 
     let reqs = Requirements.({
-      (default_requirements iface) with
+      (run iface) with
       source = true;
       command = Some "compile"}) in
 
@@ -584,7 +584,7 @@ let suite = "solver">::: [
 
   "command">:: Fake_system.with_tmpdir (fun tmpdir ->
     let (config, _fake_system) = Fake_system.get_fake_config (Some tmpdir) in
-    let r = Requirements.default_requirements (Test_0install.feed_dir +/ "command-dep.xml") in
+    let r = Requirements.run (Test_0install.feed_dir +/ "command-dep.xml") in
     let distro = Fake_distro.make config in
     let feed_provider = new Feed_provider_impl.feed_provider config distro in
     match Solver.solve_for config (feed_provider :> Feed_provider.feed_provider) r with
@@ -646,7 +646,7 @@ let suite = "solver">::: [
     let (config, _fake_system) = Fake_system.get_fake_config (Some tmpdir) in
     let uri = Test_0install.feed_dir +/ "Conflicts.xml" in
     let versions = Test_0install.feed_dir +/ "Versions.xml" in
-    let r = Requirements.default_requirements uri in
+    let r = Requirements.run uri in
 
     (* Selects 0.2 as the highest version, applying the restriction to versions < 4. *)
     let distro = Fake_distro.make config in
