@@ -4,6 +4,7 @@
 
 (** The "0install update" command *)
 
+open Zeroinstall
 open Zeroinstall.General
 open Options
 open Support.Common
@@ -87,7 +88,7 @@ let check_for_updates options reqs old_sels =
                 reqs.R.interface_uri
                 Zeroinstall.Version.fmt best.Impl.parsed_version
                 root_version;
-              if not config.help_with_testing && best.Impl.stability < Stable then
+              if not config.help_with_testing && best.Impl.stability < Stability.Stable then
                 print "To select \"testing\" versions, use:\n0install config help_with_testing True"
             ) else if not changes then (
               print "No updates found. Continuing with version %s." root_version
@@ -242,7 +243,7 @@ let handle_bg options flags args =
 
         let new_sels =
           if !need_gui || not ready || Zeroinstall.Driver.get_unavailable_selections config ~distro new_sels <> [] then (
-            let interactive_ui = Zeroinstall.Gui.try_get_gui config ~use_gui:Maybe in
+            let interactive_ui = Zeroinstall.Gui.try_get_gui config ~use_gui:`Auto in
             match interactive_ui with
             | Some gui ->
                 log_info "Background update: trying to use GUI to update %s" name;
