@@ -13,7 +13,7 @@ let type_from_url url =
   let ext =
     try U.string_tail url @@ Str.search_forward re_extension url 0
     with Not_found -> "" in
-  match String.lowercase ext with
+  match String.lowercase_ascii ext with
   | ".tar.bz2"  -> "application/x-bzip-compressed-tar"
   | ".tar.gz"   -> "application/x-compressed-tar"
   | ".tar.lzma" -> "application/x-lzma-compressed-tar"
@@ -103,7 +103,7 @@ let run_command ?cwd system args =
       match status with
       | Unix.WEXITED 0 -> Lwt.return ()
       | status ->
-          let messages = trim @@ stdout ^ stderr in
+          let messages = String.trim @@ stdout ^ stderr in
           if messages = "" then Support.System.check_exit_status status;
           raise_safe "Command failed: %s" messages
     with Safe_exception _ as ex ->
