@@ -29,22 +29,25 @@ let is_in_progress dl =
   not finished
 
 let init = lazy (
-  Curl_threading.init ();
   Curl.(global_init CURLINIT_GLOBALALL);
 )
 
 let interceptor = ref None        (* (for unit-tests) *)
 
+let is_redirect connection =
+  let code = Curl.get_httpcode connection in
+  code >= 300 && code < 400
+
 (** Download the contents of [url] into [ch].
  * This runs in a separate (either Lwt or native) thread. *)
 let download_no_follow ~cancelled ?size ?modification_time ?(start_offset=Int64.zero) ~progress connection ch url =
   let skip_bytes = ref (Int64.to_int start_offset) in
   let error_buffer = ref "" in
-  Curl_threading.catch (fun () ->
+  Lwt.catch (fun () ->
     let redirect = ref None in
     let check_header header =
       if U.starts_with header "Location:" then (
-        redirect := Some (U.string_tail header 9 |> trim)
+        redirect := Some (U.string_tail header 9 |> String.trim)
       );
       String.length header in
 
@@ -82,56 +85,60 @@ let download_no_follow ~cancelled ?size ?modification_time ?(start_offset=Int64.
     Curl.set_useragent connection ("0install/" ^ About.version);
     Curl.set_headerfunction connection check_header;
     Curl.set_progressfunction connection (fun dltotal dlnow _ultotal _ulnow ->
-      Curl_threading.run_in_main (fun () ->
         if !cancelled then true    (* Don't override the finished=true signal *)
         else (
           let dlnow = Int64.of_float dlnow in
           begin match size with
-          | Some _ -> progress (dlnow, size, false)
-          | None ->
+            | Some _ -> progress (dlnow, size, false)
+            | None ->
               let total = if dltotal = 0.0 then None else Some (Int64.of_float dltotal) in
               progress (dlnow, total, false) end;
           false  (* (continue download) *)
         )
-      )
     );
     Curl.set_noprogress connection false; (* progress = true *)
 
-    Curl_threading.perform connection (fun () ->
-      let actual_size = Curl.get_sizedownload connection in
+    Curl_lwt.perform connection >|= fun result ->
+    (* Check for redirect header first because for large redirect bodies we
+       may get a size-exceeded error rather than CURLE_OK. *)
+    match !redirect with
+    | Some target when is_redirect connection ->
+      (* ocurl is missing CURLINFO_REDIRECT_URL, so we have to do this manually *)
+      let target = Support.Urlparse.join_url url target in
+      log_info "Redirect from '%s' to '%s'" url target;
+      `Redirect target
+    | _ ->
+      match result with
+      | Curl.CURLE_OK ->
+        begin
+          let actual_size = Curl.get_sizedownload connection in
 
-      (* Curl.cleanup connection; - leave it open for the next request *)
+          (* Curl.cleanup connection; - leave it open for the next request *)
 
-      match !redirect with
-      | Some target ->
-          (* ocurl is missing CURLINFO_REDIRECT_URL, so we have to do this manually *)
-          let target = Support.Urlparse.join_url url target in
-          log_info "Redirect from '%s' to '%s'" url target;
-          `Redirect target
-      | None ->
           if modification_time <> None && actual_size = 0.0 then (
             raise Unmodified  (* ocurl is missing CURLINFO_CONDITION_UNMET *)
           ) else (
             size |> if_some (fun expected ->
-              let expected = Int64.to_float expected in
-              if expected <> actual_size then
-                raise_safe "Downloaded archive has incorrect size.\n\
-                            URL: %s\n\
-                            Expected: %.0f bytes\n\
-                            Received: %.0f bytes" url expected actual_size
-            );
+                let expected = Int64.to_float expected in
+                if expected <> actual_size then
+                  raise_safe "Downloaded archive has incorrect size.\n\
+                              URL: %s\n\
+                              Expected: %.0f bytes\n\
+                              Received: %.0f bytes" url expected actual_size
+              );
             log_info "Download '%s' completed successfully (%.0f bytes)" url actual_size;
             `Success
           )
-    )
+        end
+      | code -> raise Curl.(CurlException (code, errno code, strerror code))
   )
   (function
   | Curl.CurlException _ as ex ->
-      if !cancelled then `Aborted_by_user
+      if !cancelled then Lwt.return `Aborted_by_user
       else (
         log_info ~ex "Curl error: %s" !error_buffer;
         let msg = Printf.sprintf "Error downloading '%s': %s" url !error_buffer in
-        `Network_failure msg
+        Lwt.return (`Network_failure msg)
       )
   | ex -> raise ex
   )
@@ -186,8 +193,7 @@ module Site = struct
 
               let download () = download_no_follow ~cancelled ?modification_time ?size ?start_offset ~progress connection ch url in
 
-              Lwt.finalize
-                (fun () -> Curl_threading.detach download)
+              Lwt.finalize download
                 (fun () ->
                    timeout |> if_some Lwt_timeout.stop;
                    Lwt.return ()
