@@ -7,10 +7,8 @@
 open General
 open Support.Common
 
-module Basedir = Support.Basedir
 module FeedAttr = Constants.FeedAttr
 module F = Feed
-module R = Requirements
 module U = Support.Utils
 module Q = Support.Qdom
 module G = Support.Gpg
@@ -266,7 +264,7 @@ let get_bug_report_details config ~role (ready, results) =
   let issue_file = "/etc/issue" in
   let issue =
     if system#file_exists issue_file then
-      U.read_file system issue_file |> trim
+      U.read_file system issue_file |> String.trim
     else
       Printf.sprintf "(file '%s' not found)" issue_file in
 
@@ -321,11 +319,12 @@ let run_test config distro test_callback (ready, results) =
 
 let try_get_gui config ~use_gui =
   let system = config.system in
-  if use_gui = No then None
-  else (
+  match use_gui with
+  | `No -> None
+  | `Yes | `Auto as use_gui ->
     match system#getenv "DISPLAY" with
     | None | Some "" ->
-        if use_gui = Maybe then None
+        if use_gui = `Auto then None
         else raise_safe "Can't use GUI because $DISPLAY is not set"
     | Some _ ->
         if !gui_plugin = None then (
@@ -362,7 +361,7 @@ let try_get_gui config ~use_gui =
 
         match !gui_plugin with
         | None ->
-            if use_gui = Maybe then None
+            if use_gui = `Auto then None
             else raise_safe "Can't use GUI - plugin cannot be loaded"
         | Some gui_plugin ->
             try
@@ -370,39 +369,41 @@ let try_get_gui config ~use_gui =
             with ex ->
               log_warning ~ex "Failed to create GTK GUI";
               None
-  )
 
 let send_bug_report iface_uri message : string Lwt.t =
   let error_buffer = ref "" in
-  try
-    (* todo: Check the interface to decide where to send bug reports *)
-    let url = "http://0install.net/api/report-bug/" in
-    let connection = Curl.init () in
-    Curl.set_nosignal connection true;    (* Can't use DNS timeouts when multi-threaded *)
-    Curl.set_failonerror connection true;
-    if Support.Logging.will_log Support.Logging.Debug then Curl.set_verbose connection true;
 
-    Curl.set_errorbuffer connection error_buffer;
+  (* todo: Check the interface to decide where to send bug reports *)
+  let url = "http://api.0install.net/api/report-bug/" in
+  let connection = Curl.init () in
+  Curl.set_nosignal connection true;    (* Can't use DNS timeouts when multi-threaded *)
+  Curl.set_failonerror connection true;
+  if Support.Logging.will_log Support.Logging.Debug then Curl.set_verbose connection true;
 
-    let output_buffer = Buffer.create 256 in
-    Curl.set_writefunction connection (fun data ->
+  Curl.set_errorbuffer connection error_buffer;
+
+  let output_buffer = Buffer.create 256 in
+  Curl.set_writefunction connection (fun data ->
       Buffer.add_string output_buffer data;
       String.length data
     );
 
-    let post_data = Printf.sprintf "uri=%s&body=%s" (Curl.escape iface_uri) (Curl.escape message) in
+  let post_data = Printf.sprintf "uri=%s&body=%s" (Curl.escape iface_uri) (Curl.escape message) in
 
-    Curl.set_url connection url;
-    Curl.set_post connection true;
-    Curl.set_postfields connection post_data;
-    Curl.set_postfieldsize connection (String.length post_data);
+  Curl.set_url connection url;
+  Curl.set_post connection true;
+  Curl.set_postfields connection post_data;
+  Curl.set_postfieldsize connection (String.length post_data);
 
-    Curl.perform connection;
-
-    Lwt.return (Buffer.contents output_buffer)
-  with Curl.CurlException _ as ex ->
-    log_info ~ex "Curl error: %s" !error_buffer;
-    raise_safe "Failed to submit bug report: %s\n%s" (Printexc.to_string ex) !error_buffer
+  Lwt.finalize
+    (fun () -> Curl_lwt.perform connection)
+    (fun () -> Curl.cleanup connection; Lwt.return ())
+  >|= function
+  | Curl.CURLE_OK -> Buffer.contents output_buffer
+  | code ->
+    let msg = Curl.strerror code in
+    log_info "Curl error: %s\n%s" msg !error_buffer;
+    raise_safe "Failed to submit bug report: %s\n%s" msg !error_buffer
 
 let get_sigs config url =
   match Feed_cache.get_cached_feed_path config url with
@@ -410,13 +411,14 @@ let get_sigs config url =
   | Some cache_path ->
       if config.system#file_exists cache_path then (
         let xml = U.read_file config.system cache_path in
-        Support.Gpg.verify config.system xml >|= fun (sigs, warnings) ->
+        let gpg = Support.Gpg.make config.system in
+        Support.Gpg.verify gpg xml >|= fun (sigs, warnings) ->
         if warnings <> "" then log_info "get_last_modified: %s" warnings;
         sigs
       ) else Lwt.return []
 
 let format_para para =
-  para |> Str.split (Str.regexp_string "\n") |> List.map trim |> String.concat " "
+  para |> Str.split (Str.regexp_string "\n") |> List.map String.trim |> String.concat " "
 
 (** The formatted text for the details panel. *)
 let generate_feed_description config trust_db feed overrides =
@@ -447,7 +449,8 @@ let generate_feed_description config trust_db feed overrides =
 
       sigs |> Lwt_list.map_s (function
         | G.ValidSig {G.fingerprint; G.timestamp} ->
-            G.get_key_name config.system fingerprint >|= fun name ->
+            let gpg = G.make config.system in
+            G.get_key_name gpg fingerprint >|= fun name ->
             let is_trusted =
               if trust_db#is_trusted ~domain fingerprint then `Trusted else `Not_trusted in
             `Valid (fingerprint, timestamp, name, is_trusted)
