@@ -24,11 +24,11 @@ val download_icon : Fetch.fetcher -> Feed_provider.feed_provider -> Feed_url.non
  * The input says what the user requested:
  * No -> we never want to use the GUI
  * Yes -> we always want to use the GUI, and throw an exception if it's not available
- * Maybe -> we want to use the GUI iff it's available
+ * Auto -> we want to use the GUI iff it's available
  *
  * Returns a suitable GUI handler if so, or None if we should use a non-GUI handler.
  *)
-val try_get_gui : General.config -> use_gui:Support.Common.yes_no_maybe -> Ui.ui_handler option
+val try_get_gui : General.config -> use_gui:[< `Yes | `No | `Auto] -> Ui.ui_handler option
 
 (** Download the feed and add it as an extra feed of the interface. *)
 val add_remote_feed :
@@ -58,7 +58,7 @@ val list_impls : Solver.Model.t -> Solver.role ->
 val get_fetch_info : General.config -> Impl.generic_implementation -> (string * string)
 
 (** Set a user-override stability rating. *)
-val set_impl_stability : General.config -> Feed_url.global_id -> General.stability_level option -> unit
+val set_impl_stability : General.config -> Feed_url.global_id -> Stability.t option -> unit
 
 (** Get the initial text for the bug report dialog box. *)
 val get_bug_report_details : General.config -> role:Solver.role -> (bool * Solver.Model.t) -> string
@@ -68,6 +68,6 @@ val get_bug_report_details : General.config -> role:Solver.role -> (bool * Solve
  * @raise Safe_exception on failure. *)
 val send_bug_report : Sigs.iface_uri -> string -> string Lwt.t
 
-val run_test : General.config -> Distro.distribution -> (Selections.t -> string Lwt.t) -> (bool * Solver.Model.t) -> string Lwt.t
+val run_test : General.config -> Distro.t -> (Selections.t -> string Lwt.t) -> (bool * Solver.Model.t) -> string Lwt.t
 
 val generate_feed_description : General.config -> Trust.trust_db -> Feed.feed -> Feed.feed_overrides -> feed_description Lwt.t
