@@ -4,6 +4,14 @@
 
 (** Some useful abstract module types. *)
 
+open Support.Common
+
+type iface_uri = string
+(** A URI used to identify an interface.
+    Uses only plain URI characters, unicode chars, spaces, etc are %-escaped. *)
+
+type feed_url = string
+
 module type MAP = sig
   include Map.S
 
@@ -38,11 +46,11 @@ module type CORE_MODEL = sig
   type dep_info = {
     dep_role : Role.t;
 
-    (* If the dependency is [`essential] then its role must be filled.
+    (* If the dependency is [`Essential] then its role must be filled.
      * Otherwise, we just prefer to fill it if possible.
-     * A [`restricts] dependency does not cause the solver to try to fill a role, it just
+     * A [`Restricts] dependency does not cause the solver to try to fill a role, it just
      * adds restrictions if it is used for some other reason. *)
-    dep_importance : [ `essential | `recommended | `restricts ];
+    dep_importance : [ `Essential | `Recommended | `Restricts ];
 
     (* Any commands on [dep_role] required by this dependency. *)
     dep_required_commands : command_name list;
@@ -159,3 +167,20 @@ module type SOLVER_RESULT = sig
    * It satisfies all requirements, even conflicting ones. *)
   val dummy_impl : impl
 end
+
+module type SEARCH_PATH = sig
+  type config
+  type key
+
+  val all_paths : key -> config -> filepath list
+  (** [all_paths key config] is all configured paths for [key], in search order,
+      whether they exist currently or not. *)
+
+  val first : key -> config -> filepath option
+  (** [first key config] is the first existing path of [key] in the search path. *)
+
+  val save_path : key -> config -> filepath
+  (** [save_path key config] creates a directory for [key] in the first directory in
+      the search path (if it doesn't yet exist) and returns the path of the
+      [key] within it (which may not yet exist). *)
+end
